@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -36,7 +36,7 @@ extern NSString  *ViewWillCloseEvent;
 @class TreeContext;
 @class AnnotatedTreeContext;
 
-@interface DirectoryViewControl : NSWindowController {
+@interface DirectoryViewControl : NSWindowController<NSMenuItemValidation> {
 
   // Main window
   IBOutlet NSTextField  *itemPathField;
@@ -101,7 +101,7 @@ extern NSString  *ViewWillCloseEvent;
 @property (nonatomic, readonly, strong) AnnotatedTreeContext *annotatedTreeContext;
 
 /* Returns YES iff the action is currently enabled. 
- * 
+ *
  * Only works for a subset of of actions, e.g. openFile: and deleteFile:. See implementation for
  * complete list, which can be extended when needed.
  */
