@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -66,7 +66,6 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 
 @interface DirectoryViewControl (PrivateMethods)
 
-@property (class, nonatomic, readonly) NSColor *secondaryLabelColor;
 @property (nonatomic, readonly) BOOL canOpenSelectedFile;
 @property (nonatomic, readonly) BOOL canPreviewSelectedFile;
 @property (nonatomic, readonly) BOOL canRevealSelectedFile;
@@ -91,6 +90,7 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 
 - (void) fileSizeUnitSystemChanged;
 
+- (void) openFile:(FileItem *)fileItem withApplication:(NSURL *)appUrl;
 @end
 
 
@@ -283,8 +283,8 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 }
 
 - (void) windowDidResignMain:(NSNotification *)notification {
-  [itemSizeField setTextColor: DirectoryViewControl.secondaryLabelColor];
-  [itemPathField setTextColor: DirectoryViewControl.secondaryLabelColor];
+  [itemSizeField setTextColor: NSColor.secondaryLabelColor];
+  [itemPathField setTextColor: NSColor.secondaryLabelColor];
 }
 
 
@@ -320,42 +320,21 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 
 
 - (IBAction) openFile:(id)sender {
-  FileItem  *file = pathModelView.selectedFileItem;
-  NSString  *filePath = file.systemPath;
+  FileItem  *fileItem = pathModelView.selectedFileItem;
 
   NSUserDefaults  *userDefaults = NSUserDefaults.standardUserDefaults;
-  NSString  *customApp = [userDefaults stringForKey: CustomFileOpenApplication];
   NSWorkspace  *workspace = NSWorkspace.sharedWorkspace;
+  NSString  *customApp = [userDefaults stringForKey: CustomFileOpenApplication];
+  NSURL  *appUrl;
 
   if (customApp.length > 0) {
-    NSLog(@"Opening using customApp");
-    if ( [workspace openFile: filePath withApplication: customApp] ) {
-      return; // All went okay
-    }
+    NSLog(@"Opening %@ using custom app %@", fileItem.systemPath, customApp);
+    appUrl = [NSURL fileURLWithPath: customApp];
+  } else {
+    appUrl = [workspace URLForApplicationToOpenURL: [NSURL fileURLWithPath: fileItem.systemPath]];
   }
-  else {
-    if ( [workspace openFile: filePath] ) {
-      return; // All went okay
-    }
-  }
-  
-  NSAlert *alert = [[[NSAlert alloc] init] autorelease];
 
-  NSString  *msgFmt = 
-    ( [file isPackage]
-      ? NSLocalizedString(@"Failed to open the package \"%@\"", @"Alert message")
-      : ( [file isDirectory] 
-          // Opening directories should not be enabled, but handle it anyway
-          // here, just for robustness...
-          ? NSLocalizedString(@"Failed to open the folder \"%@\"", @"Alert message")
-          : NSLocalizedString(@"Failed to open the file \"%@\"", @"Alert message") ) );
-  NSString  *msg = [NSString stringWithFormat: msgFmt, [file pathComponent]];
-         
-  [alert addButtonWithTitle: OK_BUTTON_TITLE];
-  alert.messageText = msg;
-  [alert setInformativeText: NOTE_IT_MAY_NOT_EXIST_ANYMORE];
-
-  [alert beginSheetModalForWindow: self.window completionHandler: nil];
+  [self openFile: fileItem withApplication: appUrl];
 }
 
 - (IBAction) previewFile:(id)sender {
@@ -368,56 +347,55 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 }
 
 - (IBAction) revealFileInFinder:(id)sender {
-  FileItem  *file = pathModelView.selectedFileItem;
-  NSString  *filePath = file.systemPath;
+  FileItem  *fileItem = pathModelView.selectedFileItem;
+  NSString  *filePath = fileItem.systemPath;
   
   NSUserDefaults  *userDefaults = NSUserDefaults.standardUserDefaults;
   NSString  *customApp = [userDefaults stringForKey: CustomFileRevealApplication];
   NSWorkspace  *workspace = NSWorkspace.sharedWorkspace;
 
   if (customApp.length > 0) {
-    NSLog(@"Revealing using customApp %@.", customApp);
-    if ( [workspace openFile: filePath withApplication: customApp] ) {
-      return; // All went okay
-    }
+    NSLog(@"Revealing %@ using custom app %@", fileItem.systemPath, customApp);
+
+    [self openFile: fileItem withApplication: [NSURL fileURLWithPath: customApp]];
+    return;
   }
-  else { 
-    // Work-around for bug/limitation of NSWorkSpace. It apparently cannot select files that are
-    // inside a package, unless the package is the root path. So check if the selected file is
-    // inside a package. If so, use it as a root path.
-    DirectoryItem  *ancestor = file.parentDirectory;
-    DirectoryItem  *package = nil;
+
+  // Work-around for bug/limitation of NSWorkSpace. It apparently cannot select files that are
+  // inside a package, unless the package is the root path. So check if the selected file is
+  // inside a package. If so, use it as a root path.
+  DirectoryItem  *ancestor = fileItem.parentDirectory;
+  DirectoryItem  *package = nil;
  
-    while (ancestor != nil) {
-      if (ancestor.isPackage) {
-        if (package != nil) {
-          // The package in which the selected item resides is inside a package itself. Open this
-          // inner package instead (as opening the selected file will not succeed).
-          file = package;
-        }
-        package = ancestor;
+  while (ancestor != nil) {
+    if (ancestor.isPackage) {
+      if (package != nil) {
+        // The package in which the selected item resides is inside a package itself. Open this
+        // inner package instead (as opening the selected file will not succeed).
+        fileItem = package;
       }
-      ancestor = ancestor.parentDirectory;
-    }
-
-    NSString  *rootPath = (package != nil) ? package.systemPath : invisiblePathName;
-
-    if ([workspace selectFile: filePath inFileViewerRootedAtPath: rootPath]) {
-      return; // All went okay
+      package = ancestor;
     }
+    ancestor = ancestor.parentDirectory;
   }
-  
+
+  NSString  *rootPath = (package != nil) ? package.systemPath : invisiblePathName;
+
+  if ([workspace selectFile: filePath inFileViewerRootedAtPath: rootPath]) {
+    return; // All went okay
+  }
+
   NSAlert *alert = [[[NSAlert alloc] init] autorelease];
 
   NSString  *msgFmt = 
-    ( file.isPackage
+    ( fileItem.isPackage
       ? NSLocalizedString(@"Failed to reveal the package \"%@\"", @"Alert message")
-      : ( file.isDirectory
+      : ( fileItem.isDirectory
           ? NSLocalizedString(@"Failed to reveal the folder \"%@\"", @"Alert message")
           : NSLocalizedString(@"Failed to reveal the file \"%@\"", @"Alert message")
          )
      );
-  NSString  *msg = [NSString stringWithFormat: msgFmt, file.pathComponent];
+  NSString  *msg = [NSString stringWithFormat: msgFmt, fileItem.pathComponent];
 
   [alert addButtonWithTitle: OK_BUTTON_TITLE];
   alert.messageText = msg;
@@ -532,26 +510,37 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 
 
 - (BOOL) validateAction:(SEL)action {
-  if ( action == @selector(openFile:) ) {
+  if (action == @selector(openFile:)) {
     return self.canOpenSelectedFile;
   }
-  else if ( action == @selector(previewFile:) ) {
+  if (action == @selector(previewFile:)) {
     return self.canPreviewSelectedFile;
   }
-  else if ( action == @selector(revealFileInFinder:) ) {
+  if (action == @selector(revealFileInFinder:)) {
     return self.canRevealSelectedFile;
   }
-  else if ( action == @selector(deleteFile:) ) {
+  if (action == @selector(deleteFile:)) {
     return self.canDeleteSelectedFile;
   }
-  else if ( action == @selector(copy:) ) {
+  if (action == @selector(copy:)) {
     return self.canCopySelectedPathToPasteboard;
   }
-  
-  NSLog(@"Unsupported action");
+
   return NO;
 }
 
+- (BOOL) validateMenuItem:(NSMenuItem *)menuItem {
+  SEL action = menuItem.action;
+
+  if (action == @selector(deleteFile:)) {
+    menuItem.title = pathModelView.selectedFileItem.isDirectory
+      ? NSLocalizedStringFromTable(@"Delete Folder", @"Localizable", @"Menu item")
+      : NSLocalizedStringFromTable(@"Delete File", @"Localizable", @"Menu item");
+  }
+
+  return [self validateAction: menuItem.action];
+}
+
 
 - (BOOL) isSelectedFileLocked {
   return pathModelView.pathModel.isVisiblePathLocked;
@@ -651,58 +640,50 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
 
 @implementation DirectoryViewControl (PrivateMethods)
 
-+ (NSColor *)secondaryLabelColor {
-  // secondaryLabelColor is supported from macOS 10.10 onwards.
-  // TODO: Remove this helper method once macOS 10.9 support is dropped
-  return [NSColor respondsToSelector: @selector(secondaryLabelColor)]
-    ? NSColor.secondaryLabelColor
-    : NSColor.darkGrayColor;
-}
-
 - (BOOL) canOpenSelectedFile {
   FileItem  *selectedFile = pathModelView.selectedFileItem;
 
-  return
-    ( // Can only open actual files
-      selectedFile.isPhysical
+  return (self.isSelectedFileLocked
+
+          // Can only open actual files
+          && selectedFile.isPhysical
       
-      // Can only open plain files and packages
-      && ( !selectedFile.isDirectory || selectedFile.isPackage )
-    );
+          // Can only open plain files and packages
+          && ( !selectedFile.isDirectory || selectedFile.isPackage ));
 }
 
 - (BOOL) canPreviewSelectedFile {
-  return pathModelView.selectedFileItem.isPhysical;
+  return self.isSelectedFileLocked && pathModelView.selectedFileItem.isPhysical;
 }
 
 - (BOOL) canRevealSelectedFile {
-  return pathModelView.selectedFileItem.isPhysical;
+  return self.isSelectedFileLocked && pathModelView.selectedFileItem.isPhysical;
 }
 
 - (BOOL) canDeleteSelectedFile {
   FileItem  *selectedFile = pathModelView.selectedFileItem;
 
-  return 
-    ( // Can only delete actual files.
-      selectedFile.isPhysical
+  return (self.isSelectedFileLocked
 
-      // Can this type of item be deleted (according to the preferences)?
-      && ( (canDeleteFiles && !selectedFile.isDirectory)
-           || (canDeleteFolders && selectedFile.isDirectory) )
+          // Can only delete actual files.
+          && selectedFile.isPhysical
 
-      // Can only delete the entire scan tree when it is an actual folder 
-      // within the volume. You cannot delete the root folder.
-      && ! ( (selectedFile == pathModelView.scanTree)
-             && [pathModelView.scanTree.systemPathComponent isEqualToString: @""])
+          // Can this type of item be deleted (according to the preferences)?
+          && ((canDeleteFiles && !selectedFile.isDirectory)
+              || (canDeleteFolders && selectedFile.isDirectory))
 
-      // Don't enable Click-through for deletion. The window needs to be 
-      // active for the file deletion controls to be enabled.
-      && self.window.keyWindow
-    );
+          // Can only delete the entire scan tree when it is an actual folder
+          // within the volume. You cannot delete the root folder.
+          && ! ( (selectedFile == pathModelView.scanTree)
+                && [pathModelView.scanTree.systemPathComponent isEqualToString: @""])
+
+          // Don't enable Click-through for deletion. The window needs to be
+          // active for the file deletion controls to be enabled.
+          && self.window.keyWindow);
 }
 
 - (BOOL) canCopySelectedPathToPasteboard {
-  return YES;
+  return self.isSelectedFileLocked;
 }
 
 
@@ -847,7 +828,7 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
         
       if (relativeItemPath.length > visibleLen) {
         [attributedPath addAttribute: NSForegroundColorAttributeName
-                               value: DirectoryViewControl.secondaryLabelColor
+                               value: NSColor.secondaryLabelColor
                                range: NSMakeRange(0, relativeItemPath.length - visibleLen)];
       }
         
@@ -893,6 +874,43 @@ NSString  *ViewWillCloseEvent = @"viewWillClose";
   [self updateSelectionInStatusbar: nil];
 }
 
+- (void) openFile:(FileItem *)fileItem withApplication:(NSURL *)appUrl {
+  NSWorkspace  *workspace = NSWorkspace.sharedWorkspace;
+  NSString  *filePath = fileItem.systemPath;
+
+  [workspace openURLs: @[[NSURL fileURLWithPath: filePath]]
+ withApplicationAtURL: appUrl
+          configuration: [NSWorkspaceOpenConfiguration configuration]
+    completionHandler: ^(NSRunningApplication *app, NSError *error) {
+    if (error == nil) {
+      NSLog(@"Opened %@ using %@", filePath, appUrl);
+      return;
+    }
+
+    NSLog(@"Failed to open %@ using %@: %@", filePath, appUrl, error.description);
+    dispatch_async(dispatch_get_main_queue(), ^() {
+      NSAlert *alert = [[[NSAlert alloc] init] autorelease];
+
+      NSString  *msgFmt =
+        ( fileItem.isPackage
+          ? NSLocalizedString(@"Failed to open the package \"%@\"", @"Alert message")
+          : ( fileItem.isDirectory
+              // Opening directories should not be enabled, but handle it anyway
+              // here, just for robustness...
+              ? NSLocalizedString(@"Failed to open the folder \"%@\"", @"Alert message")
+              : NSLocalizedString(@"Failed to open the file \"%@\"", @"Alert message") ) );
+      NSString  *msg = [NSString stringWithFormat: msgFmt, fileItem.pathComponent];
+
+      [alert addButtonWithTitle: OK_BUTTON_TITLE];
+      alert.messageText = msg;
+      [alert setInformativeText: NOTE_IT_MAY_NOT_EXIST_ANYMORE];
+
+      [alert beginSheetModalForWindow: self.window completionHandler: nil];
+    });
+  }];
+}
+
+
 @end // @implementation DirectoryViewControl (PrivateMethods)
 
 
