@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -18,11 +18,11 @@
  */
 
 #import <Cocoa/Cocoa.h>
-#import "Compatibility.h"
 
 @class DirectoryViewControl;
 
-@interface DirectoryViewToolbarControl : NSObject <NSToolbarDelegate> {
+@interface DirectoryViewToolbarControl
+  : NSObject <NSToolbarDelegate, NSMenuItemValidation, NSToolbarItemValidation> {
 
   IBOutlet NSWindow  *dirViewWindow;
 
@@ -38,7 +38,6 @@
   NSUInteger  focusResetSegment;
 
   DirectoryViewControl  *dirViewControl;
-
 }
 
 @end
