@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -78,10 +78,6 @@ static const NSUInteger FOCUS_RESET_TAG = 105;
 - (void) zoom:(id)sender;
 - (void) focus:(id)sender;
 
-- (void) zoomOut:(id)sender;
-- (void) zoomIn:(id)sender;
-- (void) resetZoom:(id)sender;
-
 - (void) moveFocusUp:(id)sender;
 - (void) moveFocusDown:(id)sender;
 - (void) resetFocus:(id)sender;
@@ -291,7 +287,6 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
              ToolbarRescan,
              ToolbarShowInfo,
              ToolbarSearch,
-             NSToolbarSeparatorItemIdentifier,
              NSToolbarSpaceItemIdentifier,
              NSToolbarFlexibleSpaceItemIdentifier];
 }
@@ -378,19 +373,9 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
 
   ToolbarItemMenu  *menu =
     [[[ToolbarItemMenu alloc] initWithTitle: title target: self] autorelease];
-  NSMenuItem  *focusUpItem = [menu addAction: @selector(moveFocusUp:) withTitle: moveUpTitle];
-  NSMenuItem  *focusDownItem = [menu addAction: @selector(moveFocusDown:) withTitle: moveDownTitle];
-  NSMenuItem  *focusResetItem __unused =
-    [menu addAction: @selector(resetFocus:) withTitle: resetTitle];
-
-  // Set the key equivalents so that they show up in the menu (which may help to make the user aware
-  // of them or remind the user of them). They do not actually have an effect. Handling these key
-  // equivalents is handled in the DirectoryView class.
-  focusUpItem.keyEquivalent = @"[";
-  focusUpItem.keyEquivalentModifierMask = NSEventModifierFlagCommand;
-  
-  focusDownItem.keyEquivalent = @"]";
-  focusDownItem.keyEquivalentModifierMask = NSEventModifierFlagCommand;
+  [menu addAction: @selector(moveFocusUp:) withTitle: moveUpTitle];
+  [menu addAction: @selector(moveFocusDown:) withTitle: moveDownTitle];
+  [menu addAction: @selector(resetFocus:) withTitle: resetTitle];
 
   item.menuFormRepresentation = menu;
 
@@ -404,7 +389,8 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   [item setLabel: NSLocalizedStringFromTable(@"Open", @"Toolbar", @"Toolbar action")];
   item.paletteLabel = item.label;
   [item setToolTip: NSLocalizedStringFromTable(@"Open with Finder", @"Toolbar", @"Tooltip")];
-  item.image = [NSImage imageNamed: @"OpenWithFinder"];
+  item.image = [NSImage imageWithSystemSymbolName: @"book"
+                         accessibilityDescription: nil];
   item.action = @selector(openFile:);
   item.target = self;
 
@@ -419,7 +405,8 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   item.paletteLabel = item.label;
   [item setToolTip:
     NSLocalizedStringFromTable(@"Preview item in Quick Look panel", @"Toolbar", @"Tooltip")];
-  item.image = [NSImage imageNamed: @"QuickLook"];
+  item.image = [NSImage imageWithSystemSymbolName: @"eye"
+                         accessibilityDescription: nil];
   item.action = @selector(previewFile:);
   item.target = self;
 
@@ -433,7 +420,8 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   [item setLabel: NSLocalizedStringFromTable(@"Reveal", @"Toolbar", @"Toolbar action")];
   item.paletteLabel = item.label;
   [item setToolTip: NSLocalizedStringFromTable(@"Reveal in Finder", @"Toolbar", @"Tooltip" )];
-  item.image = [NSImage imageNamed: @"RevealInFinder"];
+  item.image = [NSImage imageWithSystemSymbolName: @"doc.viewfinder"
+                         accessibilityDescription: nil];
   item.action = @selector(revealFileInFinder:);
   item.target = self;
 
@@ -447,7 +435,8 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   [item setLabel: NSLocalizedStringFromTable(@"Delete", @"Toolbar", @"Toolbar action")];
   item.paletteLabel = item.label;
   [item setToolTip: NSLocalizedStringFromTable(@"Move to trash", @"Toolbar", @"Tooltip")];
-  item.image = [NSImage imageNamed: @"Delete"];
+  item.image = [NSImage imageWithSystemSymbolName: @"trash"
+                         accessibilityDescription: nil];
   item.action = @selector(deleteFile:);
   item.target = self;
 
@@ -471,7 +460,8 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   }
 
   item.paletteLabel = item.label;
-  item.image = [NSImage imageNamed: @"Rescan"];
+  item.image = [NSImage imageWithSystemSymbolName: @"arrow.clockwise"
+                         accessibilityDescription: nil];
   item.target = self;
 
   return item;
@@ -484,7 +474,8 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   [item setLabel: NSLocalizedStringFromTable(@"Info", @"Toolbar", @"Toolbar action")];
   item.paletteLabel = item.label;
   [item setToolTip: NSLocalizedStringFromTable(@"Show info", @"Toolbar", "Tooltip")];
-  item.image = [NSImage imageNamed: @"Info"];
+  item.image = [NSImage imageWithSystemSymbolName: @"info.circle.fill"
+                         accessibilityDescription: nil];
   item.action = @selector(showInfo:);
   item.target = dirViewControl;
 
@@ -511,9 +502,9 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   NSSegmentedControl  *control = (NSSegmentedControl *)toolbarItem.view;
   DirectoryView  *dirView = dirViewControl.directoryView;
 
-  [control setEnabled: [dirView canZoomOut] forSegment: zoomOutSegment];
-  [control setEnabled: [dirView canZoomIn] forSegment: zoomInSegment];
-  [control setEnabled: [dirView canZoomOut] forSegment: zoomResetSegment];
+  [control setEnabled: dirView.canZoomOut forSegment: zoomOutSegment];
+  [control setEnabled: dirView.canZoomIn forSegment: zoomInSegment];
+  [control setEnabled: dirView.canZoomOut forSegment: zoomResetSegment];
 
   return self; // Always enable the overall control
 }
@@ -531,71 +522,62 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   return self; // Always enable the overall control
 }
 
+//----------------------------------------------------------------------------
+// NSToolbarItemValidation
 
 - (BOOL) validateToolbarItem:(NSToolbarItem *)item {
   return [self validateAction: item.action];
 }
 
+//----------------------------------------------------------------------------
+// NSMenuItemValidation
+
 - (BOOL) validateMenuItem:(NSMenuItem *)item {
   return [self validateAction: item.action];
 }
-  
+
+//----------------------------------------------------------------------------
 
 - (BOOL) validateAction:(SEL)action {
-  if ( action == @selector(zoomOut:) ) {
-    return dirViewControl.directoryView.canZoomOut;
-  }
-  if ( action == @selector(zoomIn:) ) {
-    return dirViewControl.directoryView.canZoomIn;
-  }
-  if ( action == @selector(resetZoom:) ) {
-    return dirViewControl.directoryView.canResetZoom;
-  }
-  if ( action == @selector(moveFocusUp:) ) {
+  if (action == @selector(moveFocusUp:)) {
     if (dirViewControl.isSelectedFileLocked) {
-      return dirViewControl.directoryView.canMoveFocusUp;
+      return dirViewControl.directoryView.canMoveSelectionFocusUp;
     } else {
-      return dirViewControl.directoryView.canMoveDisplayDepthUp;
+      return dirViewControl.directoryView.canMoveDisplayFocusUp;
     }
   }
-  if ( action == @selector(moveFocusDown:) ) {
+  if (action == @selector(moveFocusDown:)) {
     if (dirViewControl.isSelectedFileLocked) {
-      return dirViewControl.directoryView.canMoveFocusDown;
+      return dirViewControl.directoryView.canMoveSelectionFocusDown;
     } else {
-      return dirViewControl.directoryView.canMoveDisplayDepthDown;
+      return dirViewControl.directoryView.canMoveDisplayFocusDown;
     }
   }
-  if ( action == @selector(resetFocus:) ) {
+  if (action == @selector(resetFocus:)) {
     if (dirViewControl.isSelectedFileLocked) {
-      return dirViewControl.directoryView.canResetFocus;
+      return dirViewControl.directoryView.canResetSelectionFocus;
     } else {
-      return dirViewControl.directoryView.canResetDisplayDepth;
+      return dirViewControl.directoryView.canResetDisplayFocus;
     }
   }
-  if ( action == @selector(openFile:) ||
-       action == @selector(previewFile:) ||
-       action == @selector(revealFileInFinder:) ||
-       action == @selector(deleteFile:) ) {
-    return ( [dirViewControl validateAction: action] &&
-    
-             // Selection must be locked, as it would otherwise change when the mouse is moved in
-             // order to click on the toolbar button.
-             dirViewControl.isSelectedFileLocked );
-  }
-  if ( action == @selector(rescan:) ) {
+  if (action == @selector(rescan:)) {
     return NSApplication.sharedApplication.mainWindow.windowController == dirViewControl;
   }
-  if ( action == @selector(refresh:) ) {
+  if (action == @selector(refresh:)) {
     return ( NSApplication.sharedApplication.mainWindow.windowController == dirViewControl &&
 
              // There must be a monitored change
             dirViewControl.treeContext.numTreeChanges > 0);
   }
-  if ( action == @selector(search:) ) {
+
+  if (action == @selector(search:)) {
+    return YES;
+  }
+
+  if ([dirViewControl validateAction: action]) {
     return YES;
   }
 
-  NSLog(@"Unrecognized action %@", NSStringFromSelector(action));
   return NO;
 }
 
@@ -604,13 +586,13 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
   NSUInteger  selected = [sender selectedSegment];
 
   if (selected == zoomInSegment) {
-    [self zoomIn: sender];
+    [dirViewControl.directoryView zoomIn: sender];
   }
   else if (selected == zoomOutSegment) {
-    [self zoomOut: sender];
+    [dirViewControl.directoryView zoomOut: sender];
   }
   else if (selected == zoomResetSegment) {
-    [self resetZoom: sender];
+    [dirViewControl.directoryView resetZoom: sender];
   }
   else {
     NSAssert1(NO, @"Unexpected selected segment: %lu", (unsigned long)selected);
@@ -620,14 +602,14 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
 
 - (void) focus:(id)sender {
   NSUInteger  selected = [sender selectedSegment];
-  
-  if ([sender selectedSegment] == focusDownSegment) {
+
+  if (selected == focusDownSegment) {
     [self moveFocusDown: sender];
   }
-  else if ([sender selectedSegment] == focusUpSegment) {
+  else if (selected == focusUpSegment) {
     [self moveFocusUp: sender];
   }
-  else if ([sender selectedSegment] == focusResetSegment) {
+  else if (selected == focusResetSegment) {
     [self resetFocus: sender];
   }
   else {
@@ -636,40 +618,27 @@ NSMutableDictionary  *createToolbarItemLookup = nil;
 }
 
 
-- (void) zoomOut:(id)sender {
-  [dirViewControl.directoryView zoomOut];
-}
-
-- (void) zoomIn:(id)sender {
-  [dirViewControl.directoryView zoomIn];
-}
-
-- (void) resetZoom:(id)sender {
-  [dirViewControl.directoryView resetZoom];
-}
-
-
 - (void) moveFocusUp:(id)sender {
   if (dirViewControl.isSelectedFileLocked) {
-    [dirViewControl.directoryView moveFocusUp];
+    [dirViewControl.directoryView moveSelectionFocusUp: sender];
   } else {
-    [dirViewControl.directoryView moveDisplayDepthUp];
+    [dirViewControl.directoryView moveDisplayFocusUp: sender];
   }
 }
 
 - (void) moveFocusDown:(id)sender {
   if (dirViewControl.isSelectedFileLocked) {
-    [dirViewControl.directoryView moveFocusDown];
+    [dirViewControl.directoryView moveSelectionFocusDown: sender];
   } else {
-    [dirViewControl.directoryView moveDisplayDepthDown];
+    [dirViewControl.directoryView moveDisplayFocusDown: sender];
   }
 }
 
 - (void) resetFocus:(id)sender {
   if (dirViewControl.isSelectedFileLocked) {
-    [dirViewControl.directoryView resetFocus];
+    [dirViewControl.directoryView resetSelectionFocus: sender];
   } else {
-    [dirViewControl.directoryView resetDisplayDepth];
+    [dirViewControl.directoryView resetDisplayFocus: sender];
   }
 }
 
