@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -18,15 +18,13 @@
  */
 
 #import <Cocoa/Cocoa.h>
-#import "Compatibility.h"
 
 @class FilterTestRepository;
 @class FilterTestEditor;
 @class NamedFilter;
 @protocol NameValidator;
 
-/**
- * A control for a FilterWindow.
+/* A control for a FilterWindow.
  *
  * The control fires "okPerformed", "cancelPerformed", "applyPerformed", and "closePerformed"
  * notifications to signal that respectively the OK, Cancel, Apply and Close buttons have been
