@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -28,7 +28,7 @@
 @class StartWindowControl;
 @class ExportAsTextDialogControl;
 
-@interface MainMenuControl : NSObject {
+@interface MainMenuControl : NSObject<NSMenuItemValidation> {
   WindowManager  *windowManager;
   
   VisibleAsynchronousTaskManager  *scanTaskManager;
