@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -499,59 +499,37 @@ static dispatch_once_t  singletonOnceToken;
   [self loadScanDataFromFile: fileUrl.path];
 }
 
+//----------------------------------------------------------------------------
+// NSMenuItemValidation
 
 - (BOOL) validateMenuItem:(NSMenuItem *)item {
   SEL  action = item.action;
 
+  if (action == @selector(scanDirectoryView:) ||
+      action == @selector(scanFilteredDirectoryView:) ||
+      action == @selector(scanFilteredDirectoryView:) ||
+      action == @selector(loadScanData:) ||
+      action == @selector(openWebsite:) ||
+      action == @selector(editPreferences:) ||
+      action == @selector(editFilters:) ||
+      action == @selector(editUniformTypeRanking:)) {
+    return YES;
+  }
+
+  // The remaining actions require an active Directory View window
   NSWindow  *window = NSApplication.sharedApplication.mainWindow;
   BOOL  mainWindowIsDirectoryView =
     [window.windowController isMemberOfClass:[DirectoryViewControl class]];
-  DirectoryViewControl  *dirViewControl =
-    mainWindowIsDirectoryView ? (DirectoryViewControl *)window.windowController : nil;
 
-  if ( action == @selector(toggleToolbarShown:) ) {
-    if (!mainWindowIsDirectoryView) {
-      return NO;
-    }
-    item.title = window.toolbar.visible
-       ? NSLocalizedStringFromTable(@"Hide Toolbar", @"Toolbar", @"Menu item")
-       : NSLocalizedStringFromTable(@"Show Toolbar", @"Toolbar", @"Menu item");
-
-    return YES;
+  if (!mainWindowIsDirectoryView) {
+    return NO;
   }
 
-  if ( action == @selector(toggleControlPanelShown:) ) {
-    if (!mainWindowIsDirectoryView) {
-      return NO;
-    }
-    item.title = ControlPanelControl.singletonInstance.isPanelShown
-      ? NSLocalizedString(@"Hide Control Panel", @"Menu item")
-      : NSLocalizedString(@"Show Control Panel", @"Menu item");
-
-    return YES;
-  }
-
-  if ( action == @selector(rescanSelected:) ) {
-    // Selection must be locked
-    return dirViewControl.isSelectedFileLocked;
-  }
-
-  if ( action == @selector(rescanWithMaskAsFilter:) ) {
-    // There should be a mask
-    return dirViewControl.directoryViewControlSettings.displaySettings.fileItemMaskEnabled;
-  }
-
-  if ( action == @selector(refresh:) ) {
-    // There must be a monitored change
-    return dirViewControl.treeContext.numTreeChanges > 0;
-  }
-
-  if (
-      action == @selector(duplicateDirectoryView:) ||
+  if (action == @selector(duplicateDirectoryView:) ||
       action == @selector(twinDirectoryView:)  ||
 
       action == @selector(customizeToolbar:) ||
-       
+
       action == @selector(saveScanData:) ||
       action == @selector(saveDirectoryViewImage:) ||
       action == @selector(saveScanDataAsText:) ||
@@ -562,12 +540,52 @@ static dispatch_once_t  singletonOnceToken;
 
       action == @selector(filterDirectoryView:)
   ) {
-    return mainWindowIsDirectoryView;
+    return YES;
   }
-  
-  return YES;
+
+  if (action == @selector(toggleToolbarShown:)) {
+    item.title = window.toolbar.visible
+       ? NSLocalizedStringFromTable(@"Hide Toolbar", @"Toolbar", @"Menu item")
+       : NSLocalizedStringFromTable(@"Show Toolbar", @"Toolbar", @"Menu item");
+
+    return YES;
+  }
+
+  if (action == @selector(toggleControlPanelShown:)) {
+    item.title = ControlPanelControl.singletonInstance.isPanelShown
+      ? NSLocalizedString(@"Hide Control Panel", @"Menu item")
+      : NSLocalizedString(@"Show Control Panel", @"Menu item");
+
+    return YES;
+  }
+
+  DirectoryViewControl  *dirViewControl = (DirectoryViewControl *)window.windowController;
+
+  if (action == @selector(rescanSelected:)) {
+    // Selection must be locked
+    return dirViewControl.isSelectedFileLocked;
+  }
+
+  if (action == @selector(rescanWithMaskAsFilter:)) {
+    // There should be a mask
+    return dirViewControl.directoryViewControlSettings.displaySettings.fileItemMaskEnabled;
+  }
+
+  if (action == @selector(refresh:)) {
+    // There must be a monitored change
+    return dirViewControl.treeContext.numTreeChanges > 0;
+  }
+
+
+  if ([dirViewControl validateAction: action]) {
+    return YES;
+  }
+
+  return NO;
 }
 
+//----------------------------------------------------------------------------
+
 - (IBAction) scanDirectoryView:(id)sender {
   [self scanFolderSelectingFilter: NO];
 }
