@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -63,12 +63,11 @@ NSString  *DefaultViewWindowHeight = @"defaultViewWindowHeight";
 NSString  *CustomFileOpenApplication = @"customFileOpenApplication";
 NSString  *CustomFileRevealApplication = @"customFileRevealApplication";
 NSString  *UpdateFiltersBeforeUse = @"updateFiltersBeforeUse";
-NSString  *TreeMemoryZoneKey = @"treeMemoryZone";
 NSString  *DelayBeforeWelcomeWindowAfterStartupKey = @"delayBeforeWelcomeWindowAfterStartup";
 NSString  *KeyboardNavigationDeltaKey = @"keyboardNavigationDelta";
 NSString  *PackageCheckBehaviorKey = @"packageCheckBehavior";
 
-NSString  *UnlimitedDisplayFocusValue = @"Unlimited";
+NSString  *UnlimitedDisplayFocusValue = @"unlimited";
 
 @interface PreferencesPanelControl (PrivateMethods)
 
@@ -279,8 +278,10 @@ static BOOL appHasDeletePermission;
                 select: [title isEqualToString: prefValue]];
   }
 
-  NSString  *title = NSLocalizedString(UnlimitedDisplayFocusValue,
-                                       @"Value for display focus preference setting");
+  NSString  *title = [NSBundle.mainBundle localizedStringForKey: UnlimitedDisplayFocusValue
+                                                          value: nil
+                                                          table: @"Names"];
+
   [tagMaker addValue: UnlimitedDisplayFocusValue
            withTitle: title
              toPopUp: popUp
