@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -35,9 +35,8 @@ extern NSString  *UniformTypesRankingKey;
 
 @interface UniformTypeRanking : NSObject {
 
-  // Ordered list of all known types (UniformType)
-  NSMutableArray  *rankedTypes;
-
+  // Ordered list of all known types
+  NSMutableArray<UniformType *>  *rankedTypes;
 }
 
 @property (class, nonatomic, readonly) UniformTypeRanking *defaultUniformTypeRanking;
