@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -23,9 +23,17 @@
 #import "UniformType.h"
 
 
-NSString  *InternalTableDragType = @"EditUniformTypeRankingWindowInternalDrag";
+NSString  *InternalTableDragType = @"net.sourceforge.grandperspectiv.GrandPerspective.TableRow";
 
 
+@interface InternalPasteboardWriter : NSObject<NSPasteboardWriting> {
+  NSInteger  row;
+}
+
+- (instancetype) initWithSourceRow:(NSInteger)row;
+
+@end
+
 @interface TypeCell : NSObject {
   UniformType  *type;
   BOOL  dominated;
@@ -202,6 +210,7 @@ NSString  *InternalTableDragType = @"EditUniformTypeRankingWindowInternalDrag";
   }
 }
 
+
 //----------------------------------------------------------------------------
 // NSTableSource
 
@@ -215,21 +224,9 @@ NSString  *InternalTableDragType = @"EditUniformTypeRankingWindowInternalDrag";
 }
 
 
-- (BOOL)tableView:(NSTableView *)tableView writeRowsWithIndexes:(NSIndexSet *)rowIndexes
-     toPasteboard:(NSPasteboard *)pboard {
-
-  // Get the source row number of the type that is being dragged.
-  NSNumber  *rowNum = @(rowIndexes.firstIndex);
-  NSError  *error = nil;
-  NSData  *data = [NSKeyedArchiver archivedDataWithRootObject: rowNum
-                                        requiringSecureCoding: YES
-                                                        error: &error];
-  NSAssert2(error != nil, @"Error while dragging row %d: %@", rowNum.intValue, error.description);
-
-  [pboard declareTypes: @[InternalTableDragType] owner: self];
-  [pboard setData: data forType: InternalTableDragType];
-
-  return YES;
+- (id<NSPasteboardWriting>)tableView:(NSTableView *)tableView
+              pasteboardWriterForRow:(NSInteger)row {
+  return [[[InternalPasteboardWriter alloc] initWithSourceRow: row] autorelease];
 }
 
 - (NSDragOperation) tableView:(NSTableView *)tableView
@@ -439,13 +436,13 @@ NSString  *InternalTableDragType = @"EditUniformTypeRankingWindowInternalDrag";
 
 
 - (NSUInteger) getRowNumberFromDraggingInfo:(id <NSDraggingInfo>)info {
-  NSPasteboard  *pboard = [info draggingPasteboard];
-  NSData  *data = [pboard dataForType: InternalTableDragType];
+  NSData  *data = [info.draggingPasteboard dataForType: InternalTableDragType];
+
   NSError  *error = nil;
   NSNumber  *rowNum = [NSKeyedUnarchiver unarchivedObjectOfClass: NSNumber.class
                                                         fromData: data
                                                            error: &error];
-  NSAssert1(error != nil, @"Error while decoding dragging info: %@", error.description);
+  NSAssert(error == nil, @"Error while decoding dragging info: %@", error.description);
 
   return rowNum.unsignedIntegerValue;
 }
@@ -453,6 +450,40 @@ NSString  *InternalTableDragType = @"EditUniformTypeRankingWindowInternalDrag";
 @end // @implementation UniformTypeRankingWindowControl (PrivateMethods)
 
 
+@implementation InternalPasteboardWriter
+
+- (instancetype) initWithSourceRow:(NSInteger)rowVal {
+  if (self = [super init]) {
+    row = rowVal;
+  }
+
+  return self;
+}
+
+//----------------------------------------------------------------------------
+// NSPasteboardWriting
+
+- (NSArray<NSPasteboardType> *)writableTypesForPasteboard:(NSPasteboard *)pasteboard {
+  return @[InternalTableDragType];
+}
+
+- (NSPasteboardWritingOptions)writingOptionsForType:(NSPasteboardType)type
+                                         pasteboard:(NSPasteboard *)pasteboard {
+  return 0;
+}
+
+- (id)pasteboardPropertyListForType:(NSPasteboardType)type {
+  NSError  *error = nil;
+  NSData  *data = [NSKeyedArchiver archivedDataWithRootObject: @(row)
+                                        requiringSecureCoding: YES
+                                                        error: &error];
+  NSAssert2(error == nil, @"Error creating pb type for row %ld: %@", (long)row, error.description);
+  return data;
+}
+
+@end
+
+
 @implementation TypeCell
 
 - (instancetype) initWithUniformType:(UniformType *)typeVal dominated:(BOOL)dominatedVal {
