@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -22,8 +22,7 @@
 #import "FileItem.h"
 #import "TimeBasedMapping.h"
 
-@interface MappingByAccess : TimeBasedMapping {
-}
+@interface MappingByAccess : TimeBasedMapping
 @end // @interface MappingByAccess
 
 
