@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -28,24 +28,19 @@
 #import "CreationMappingScheme.h"
 #import "ModificationMappingScheme.h"
 
-@interface MappingByLevel : StatelessFileItemMapping {
-}
+@interface MappingByLevel : StatelessFileItemMapping
 @end
 
-@interface MappingByExtension : StatelessFileItemMapping {
-}
+@interface MappingByExtension : StatelessFileItemMapping
 @end
 
-@interface MappingByFilename : StatelessFileItemMapping {
-}
+@interface MappingByFilename : StatelessFileItemMapping
 @end
 
-@interface MappingByDirectoryName : StatelessFileItemMapping {
-}
+@interface MappingByDirectoryName : StatelessFileItemMapping
 @end
 
-@interface MappingByTopDirectoryName : StatelessFileItemMapping {
-}
+@interface MappingByTopDirectoryName : StatelessFileItemMapping
 @end
 
 @implementation MappingByLevel
