@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -28,7 +28,5 @@
  * Given that the implementation is stateless, the corresponding file item mapping scheme can always
  * return the same file item mapping instance, which therefore can also represent the scheme.
  */
-@interface StatelessFileItemMapping : NSObject <FileItemMappingScheme, FileItemMapping> {
-}
-
+@interface StatelessFileItemMapping : NSObject <FileItemMappingScheme, FileItemMapping>
 @end
