@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -23,7 +23,8 @@ NS_ASSUME_NONNULL_BEGIN
 
 @class FileItemTest;
 
-@interface OverlayDrawTaskInput : DrawTaskInput
+@interface OverlayDrawTaskInput : DrawTaskInput {
+}
 
 // Override designated initializer of super.
 - (instancetype) initWithVisibleTree:(FileItem *)visibleTree
