@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -60,8 +60,7 @@
     return items[0];
   }
   else if (items.count == 2) {
-    return
-      [NSString stringWithFormat: pairTemplate, items[0], items[1]];
+    return [NSString stringWithFormat: pairTemplate, items[0], items[1]];
   }
   else {
     NSEnumerator  *itemEnum = [items reverseObjectEnumerator];
@@ -69,7 +68,7 @@
     NSString  *item = [itemEnum nextObject]; // Last item
     NSString  *s = [NSString stringWithFormat: bootstrapTemplate, [itemEnum nextObject], item];
 
-    while ( item = [itemEnum nextObject] ) {
+    while (item = [itemEnum nextObject]) {
       s = [NSString stringWithFormat: repeatingTemplate, item, s];
     }
     
