@@ -1,4 +1,4 @@
-/* GrandPerspective, Version 3.3 
+/* GrandPerspective, Version 3.4 
  *   A utility for Mac OS X that graphically shows disk usage. 
  * Copyright (C) 2005-2022, Erwin Bonsma 
  * 
@@ -18,13 +18,10 @@
  */
 
 #import <Cocoa/Cocoa.h>
-#import "Compatibility.h"
 
-/**
- * Panel which notifies its delegate when its first responder changed.
+/* Panel which notifies its delegate when its first responder changed.
  */
 @interface NotifyingPanel : NSPanel <NSWindowDelegate> {
-
 }
 
 // Method which can be implemented by delegate
